@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from enum import Enum, auto
 
-from entity.printable import Printable
+from robinhood_commons.entity.printable import Printable
 
 
 class Direction(Printable, Enum):
@@ -15,14 +15,14 @@ class Direction(Printable, Enum):
         v: str = value.upper()
         return Direction[v]
 
-    def value(self) -> str:
+    def __str__(self) -> str:
         return self.name.lower()
 
 
 def main() -> None:
     print(Direction.to_enum("down"))
     print(Direction.to_enum("neutral"))
-    print(Direction.UP.value())
+    print(Direction.UP)
 
 
 if __name__ == "__main__":
