@@ -1,10 +1,4 @@
 
-BASE_PATH: str = '/robinhood_data/'
-LOG_DIR: str = f'output/logs/'
-TMP_DIR = f'tmp/'
-
-STOCKS_FILE_PATH: str = f'{TMP_DIR}stocks.json'
-
 MAIN_EMAIL: str = 'mhowell234@gmail.com'
 USERS_KEY: str = 'users'
 DEFAULT_DELIMITER: str = ':'
