@@ -2,22 +2,22 @@ import logging
 from logging import Logger
 from logging.handlers import TimedRotatingFileHandler
 
-from log.gzip_rotator import GZipRotator
+from robinhood_commons.log.gzip_rotator import GZipRotator
 from robinhood_commons.util.io_utils import ensure_exists
 
 
-def create_logger(name: str) -> Logger:
+def create_logger(path: str) -> Logger:
     """
     Creates a rotating log
     """
 
-    ensure_exists(name)
+    ensure_exists(path)
 
-    log_name: str = name.split('/')[-1]
+    log_name: str = path.split('/')[-1]
     logger = logging.getLogger(log_name.split('.')[0])
     logger.setLevel(logging.INFO)
 
-    log_handler = TimedRotatingFileHandler(filename=name, when='h')
+    log_handler = TimedRotatingFileHandler(filename=path, when='h')
 
     log_formatter = logging.Formatter('%(asctime)s [%(levelname)s] [%(name)s] %(message)s')
     log_handler.setFormatter(log_formatter)
